{ config, inputs, pkgs, ... }:
{
  programs.direnv = {
    enable = true;
    enableBashIntegration = true;
    nix-direnv.enable = true;
  };
  programs.bash = {
    enable = true;
    bashrcExtra = ''
      eval "$(direnv hook bash)"
    '';
  };

  programs.wezterm = {
    package = inputs.wezterm.packages.${pkgs.system}.default;
    enable = true;
    enableBashIntegration = true;

    extraConfig = ''
      return {
        enable_wayland = true
      }
    '';
  };

  home.username = "nero";
  home.homeDirectory = "/home/nero";

  home.stateVersion = "25.05";
  home.file = {
    ".terraformrc".text = ''
      provider_installation {
        network_mirror {
          url = "https://terraform-mirror.yandexcloud.net/"
          include = ["registry.terraform.io/*/*"]
        }
        direct {
          exclude = ["registry.terraform.io/*/*"]
        }
      }
    '';
    ".cargo/config.toml" = {
      text = ''
        [net]
        git-fetch-with-cli = true 

        [target.x86_64-unknown-linux-gnu] 
        linker = "${pkgs.clang}/bin/clang" 
        rustflags = ["-C", "link-arg=--ld-path=${pkgs.mold}/bin/mold"]
      '';
    };
  };
  dconf.settings = {
    "org/gnome/desktop/interface" = {
      color-scheme = "prefer-dark";
      gtk-theme = "Adwaita-dark";
    };
  };

  gtk = {
    enable = true;
    theme = {
      name = "Adwaita-dark";
      package = pkgs.gnome-themes-extra;
    };
  };
  xdg.portal = {
    enable = true;
    extraPortals = with pkgs; [ xdg-desktop-portal-gtk ];
    configPackages = with pkgs; [ xdg-desktop-portal-gtk ];
  };
  qt = {
    enable = true;
    platformTheme.name = "Adwaita-dark";
    style = {
      name = "Adwaita-dark";
      package = pkgs.adwaita-qt;
    };
  };
}
